==> vokoscreen-ng_3.0.5.orig.tar.gz: vokoscreenNG-3.0.5/src/language/pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Mudar para ecrã inteiro</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Contagem decrescente</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não é iniciada, sem espaço em disco disponível.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>É alcançado o limite de espaço em disco disponível.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço em disco disponível</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi parada, sem espaço em disco disponível.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>A sessão de área de trabalho é uma sessão de Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Neste momento o Wayland não é suportado. Uma transmissão mostra um ecrã a negro. Por favor saia da conta e inicie uma sessão de Área de trabalho X11</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Página inicial</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doar</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Detetada sessão de área de trabalho Wayland</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restabelecer</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem descrescente</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço de disco disponível:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de áudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do rato</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o cronómetro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Parar a gravação após</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Caminho do vídeo </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite do espaço em disco disponível</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na barra de tarefas</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Espera em segundos antes de começar a gravar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Procurar por atualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Indisponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar relatório</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproduzir a última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizado quando a gravação começar</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doar</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Repor todas as configurações no próximo início</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Captura de ecrã em vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Leitor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registos</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Imagem anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Imagem seguinte</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover o menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.0.9.orig.tar.gz: vokoscreenNG-3.0.9/src/language/pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Mudar para ecrã inteiro</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Contagem decrescente</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não é iniciada, sem espaço em disco disponível.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Foi alcançado o limite de espaço em disco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre em disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi parada, sem espaço em disco disponível.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Página inicial</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doar</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Abrir Ficheiro</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>Qvk_wl_MainWindow</name>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Foi detectada uma sessão de área de trabalho Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Por enquanto o Wayland não é suportado. Uma transmissão mostra um ecrã a negro. Por favor, saia da sessão e inicie uma sessão de Área de trabalho X11</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover a moldura da janela</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restabelecer</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem decrescente</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço de disco disponível:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de áudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do rato</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o cronómetro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Parar a gravação após</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Caminho do vídeo </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite do espaço em disco disponível</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na barra de tarefas</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Esperar em segundos antes de iniciar a gravar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Procurar por atualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Indisponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar Relatório</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproduzir a última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar quando a gravação Iniciar</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover a moldura da janela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doar</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Repor todas as configurações no próximo início</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Captura de ecrã em vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Leitor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registos</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir Ficheiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Imagem anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Imagem seguinte</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover o menu</translation>
    </message>
</context>
</TS>
